package ij.plugin.frame;

import ij.IJ;
import ij.Prefs;
import ij.WindowManager;
import ij.gui.GUI;
import ij.gui.TextRoi;
import ij.plugin.PlugIn;
//import java.awt.Checkbox;
//import java.awt.Choice;
import java.awt.FlowLayout;
import java.awt.Font;
//import java.awt.Frame;
import java.awt.GraphicsEnvironment;
//import java.awt.Panel;
import java.awt.Point;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JPanel;


/** Displays a window that allows the user to set the font, size and style. */
public class Fonts extends PlugInFrame implements PlugIn, ItemListener {

	public static final String LOC_KEY = "fonts.loc";
	private static String[] sizes = {"8","9","10","12","14","18","24","28","36","48","60","72","100","150","225","350"};
	private static int[] isizes = {8,9,10,12,14,18,24,28,36,48,60,72,100,150,225,350};
	private JPanel panel;
	private JComboBox font;
	private JComboBox size;
	private JComboBox style;
	private JCheckBox checkbox;
	private static JFrame instance;

	public Fonts() {
		super("Fonts");
		if (instance!=null) {
			WindowManager.toFront(instance);
			return;
		}
		WindowManager.addWindow(this);
		instance = this;
		setLayout(new FlowLayout(FlowLayout.CENTER, 10, 5));

		font = new JComboBox();
		GraphicsEnvironment ge = GraphicsEnvironment.getLocalGraphicsEnvironment();
		String[] fonts = ge.getAvailableFontFamilyNames();
		font.addItem("SansSerif");
		font.addItem("Serif");
		font.addItem("Monospaced");
		for (int i=0; i<fonts.length; i++) {
			String f = fonts[i];
			if (!(f.equals("SansSerif")||f.equals("Serif")||f.equals("Monospaced")))
				font.addItem(f);
		}
		font.setSelectedItem(TextRoi.getFont());
		font.addItemListener(this);
		add(font);

		size = new JComboBox();
		for (int i=0; i<sizes.length; i++)
			size.addItem(sizes[i]);
		size.setSelectedItem(getSizeIndex());
		size.addItemListener(this);
		add(size);

		style = new JComboBox();
		style.addItem("Plain");
		style.addItem("Bold");
		style.addItem("Italic");
		style.addItem("Bold+Italic");
		style.addItem("Center");
		style.addItem("Right");
		style.addItem("Center+Bold");
		style.addItem("Right+Bold");
		int i = TextRoi.getStyle();
		int justificaton = TextRoi.getGlobalJustification();
		String s = "Plain";
		if (i==Font.BOLD) {
			if (justificaton==TextRoi.CENTER)
				s = "Center+Bold";
			else if (justificaton==TextRoi.RIGHT)
				s = "Right+Bold";
			else
				s = "Bold";
		} else if (i==Font.ITALIC)
			s = "Italic";
		else if (i==(Font.BOLD+Font.ITALIC))
			s = "Bold+Italic";
		else if (i==Font.PLAIN) {
			if (justificaton==TextRoi.CENTER)
				s = "Center";
			else if (justificaton==TextRoi.RIGHT)
				s = "Right";
		}
		style.setSelectedItem(s);
		style.addItemListener(this);
		add(style);

		checkbox = new JCheckBox("Smooth", TextRoi.isAntialiased());
		add(checkbox);
		checkbox.addItemListener(this);

		pack();
		Point loc = Prefs.getLocation(LOC_KEY);
		if (loc!=null)
			setLocation(loc);
		else
			GUI.center(this);
		setVisible(true);
		IJ.register(Fonts.class);
	}

	int getSizeIndex() {
		int size = TextRoi.getSize();
		int index=0;
		for (int i=0; i<isizes.length; i++) {
			if (size>=isizes[i])
				index = i;
		}
		return index;
	}

	public void itemStateChanged(ItemEvent e) {
		String fontName = (String)font.getSelectedItem();
		int fontSize = Integer.parseInt((String)size.getSelectedItem());
		String styleName = (String)style.getSelectedItem();
		int fontStyle = Font.PLAIN;
		int justification = TextRoi.LEFT;
		if (styleName.endsWith("Bold"))
			fontStyle = Font.BOLD;
		else if (styleName.equals("Italic"))
			fontStyle = Font.ITALIC;
		else if (styleName.equals("Bold+Italic"))
			fontStyle = Font.BOLD+Font.ITALIC;
		if (styleName.startsWith("Center"))
			justification = TextRoi.CENTER;
		else if (styleName.startsWith("Right"))
			justification = TextRoi.RIGHT;
		TextRoi.setFont(fontName, fontSize, fontStyle, checkbox.isSelected());
		TextRoi.setGlobalJustification(justification);
		IJ.showStatus(fontSize+" point "+fontName + " " + styleName);
	}

    public void close() {
	 	super.close();
		instance = null;
		Prefs.saveLocation(LOC_KEY, getLocation());
	}

}
